==> kbfs-1.0.48.tar.gz: kbfs-1.0.48/libhttpserver/server_test.go <==
// Copyright 2018 Keybase Inc. All rights reserved.
// Use of this source code is governed by a BSD
// license that can be found in the LICENSE file.

package libhttpserver

import (
	"fmt"
	"net/http"
	"os"
	"testing"

	"github.com/keybase/client/go/libkb"
	"github.com/keybase/kbfs/ioutil"
	"github.com/keybase/kbfs/libkbfs"
	"github.com/keybase/kbfs/tlf"
	"github.com/stretchr/testify/require"
)

func makeTestKBFSConfig(t *testing.T) (
	kbfsConfig libkbfs.Config, shutdown func()) {
	ctx := libkbfs.BackgroundContextWithCancellationDelayer()
	cfg := libkbfs.MakeTestConfigOrBustLoggedInWithMode(
		t, 0, libkbfs.InitSingleOp, "alice", "bob")

	tempdir, err := ioutil.TempDir(os.TempDir(), "journal_server")
	require.NoError(t, err)
	defer func() {
		if err != nil {
			ioutil.RemoveAll(tempdir)
		}
	}()
	err = cfg.EnableDiskLimiter(tempdir)
	require.NoError(t, err)
	err = cfg.EnableJournaling(
		ctx, tempdir, libkbfs.TLFJournalSingleOpBackgroundWorkEnabled)
	require.NoError(t, err)
	shutdown = func() {
		libkbfs.CheckConfigAndShutdown(ctx, t, cfg)
		err := ioutil.RemoveAll(tempdir)
		require.NoError(t, err)
	}

	h, err := libkbfs.ParseTlfHandle(
		ctx, cfg.KBPKI(), cfg.MDOps(), "alice,bob", tlf.Private)
	require.NoError(t, err)

	root, _, err := cfg.KBFSOps().GetOrCreateRootNode(ctx, h, libkbfs.MasterBranch)
	require.NoError(t, err)
	_, _, err = cfg.KBFSOps().CreateFile(ctx, root, "test.txt", false, false)
	require.NoError(t, err)

	return cfg, shutdown
}

func TestServerDefault(t *testing.T) {
	kbfsConfig, shutdown := makeTestKBFSConfig(t)
	defer shutdown()

	s, err := New(libkb.NewGlobalContext().Init(), kbfsConfig)
	require.NoError(t, err)

	addr, err := s.Address()
	require.NoError(t, err)

	token, err := s.NewToken()
	require.NoError(t, err)

	resp, err := http.Get(fmt.Sprintf(
		"http://%s/files/private/alice,bob/non-existent", addr))
	require.NoError(t, err)
	require.Equal(t, http.StatusForbidden, resp.StatusCode)

	resp, err = http.Get(fmt.Sprintf(
		"http://%s/files/private/alice,bob/non-existent?token=deadbeaf", addr))
	require.NoError(t, err)
	require.Equal(t, http.StatusForbidden, resp.StatusCode)

	resp, err = http.Get(fmt.Sprintf(
		"http://%s/files/private/alice,bob/non-existent?token=%s", addr, token))
	require.NoError(t, err)
	require.Equal(t, http.StatusNotFound, resp.StatusCode)

	resp, err = http.Get(fmt.Sprintf(
		"http://%s/files/private/alice,bob/test.txt?token=%s", addr, token))
	require.NoError(t, err)
	require.Equal(t, http.StatusOK, resp.StatusCode)

	resp, err = http.Get(fmt.Sprintf(
		"http://%s/files/blah/alice,bob/non-existent?token=%s", addr, token))
	require.NoError(t, err)
	require.Equal(t, http.StatusBadRequest, resp.StatusCode)
}

==> kbfs-2.6.0.tar.gz: kbfs-2.6.0/libhttpserver/server_test.go <==
// Copyright 2018 Keybase Inc. All rights reserved.
// Use of this source code is governed by a BSD
// license that can be found in the LICENSE file.

package libhttpserver

import (
	"fmt"
	"net/http"
	"os"
	"testing"

	"github.com/keybase/kbfs/env"
	"github.com/keybase/kbfs/ioutil"
	"github.com/keybase/kbfs/libkbfs"
	"github.com/keybase/kbfs/tlf"
	"github.com/stretchr/testify/require"
)

func makeTestKBFSConfig(t *testing.T) (
	kbfsConfig libkbfs.Config, shutdown func()) {
	ctx := libkbfs.BackgroundContextWithCancellationDelayer()
	cfg := libkbfs.MakeTestConfigOrBustLoggedInWithMode(
		t, 0, libkbfs.InitSingleOp, "alice", "bob")

	tempdir, err := ioutil.TempDir(os.TempDir(), "journal_server")
	require.NoError(t, err)
	defer func() {
		if err != nil {
			ioutil.RemoveAll(tempdir)
		}
	}()
	err = cfg.EnableDiskLimiter(tempdir)
	require.NoError(t, err)
	err = cfg.EnableJournaling(
		ctx, tempdir, libkbfs.TLFJournalSingleOpBackgroundWorkEnabled)
	require.NoError(t, err)
	shutdown = func() {
		libkbfs.CheckConfigAndShutdown(ctx, t, cfg)
		err := ioutil.RemoveAll(tempdir)
		require.NoError(t, err)
	}

	h, err := libkbfs.ParseTlfHandle(
		ctx, cfg.KBPKI(), cfg.MDOps(), "alice,bob", tlf.Private)
	require.NoError(t, err)

	root, _, err := cfg.KBFSOps().GetOrCreateRootNode(ctx, h, libkbfs.MasterBranch)
	require.NoError(t, err)
	_, _, err = cfg.KBFSOps().CreateFile(ctx, root, "test.txt", false, false)
	require.NoError(t, err)

	return cfg, shutdown
}

func TestServerDefault(t *testing.T) {
	kbfsConfig, shutdown := makeTestKBFSConfig(t)
	defer shutdown()

	s, err := New(env.EmptyAppStateUpdater{}, kbfsConfig)
	require.NoError(t, err)

	addr, err := s.Address()
	require.NoError(t, err)

	token, err := s.NewToken()
	require.NoError(t, err)

	resp, err := http.Get(fmt.Sprintf(
		"http://%s/files/private/alice,bob/non-existent", addr))
	require.NoError(t, err)
	require.Equal(t, http.StatusForbidden, resp.StatusCode)

	resp, err = http.Get(fmt.Sprintf(
		"http://%s/files/private/alice,bob/non-existent?token=deadbeaf", addr))
	require.NoError(t, err)
	require.Equal(t, http.StatusForbidden, resp.StatusCode)

	resp, err = http.Get(fmt.Sprintf(
		"http://%s/files/private/alice,bob/non-existent?token=%s", addr, token))
	require.NoError(t, err)
	require.Equal(t, http.StatusNotFound, resp.StatusCode)

	resp, err = http.Get(fmt.Sprintf(
		"http://%s/files/private/alice,bob/test.txt?token=%s", addr, token))
	require.NoError(t, err)
	require.Equal(t, http.StatusOK, resp.StatusCode)

	resp, err = http.Get(fmt.Sprintf(
		"http://%s/files/blah/alice,bob/non-existent?token=%s", addr, token))
	require.NoError(t, err)
	require.Equal(t, http.StatusBadRequest, resp.StatusCode)
}
